@@ -8,15 +8,20 @@ import matplotlib.patches as mpatches
 import numpy as np
 
 
-def plot_results(data, inf_res, bins=50, output = "results.png",fig_height = 10, fig_width = 8):
+def plot_results(data, inf_res, bins=50, output = "results.png",fig_height = 4, fig_width = 3):
 
     all_params = inf_res["model_parameters"]
-    plt.rcParams["figure.figsize"] = (fig_height, fig_width)
     tail = inf_res['run_parameters']['tail']
-    fig, axs = plt.subplots(len(all_params))
+    nKar = len(all_params)
+    plt.rcParams["figure.figsize"] = (fig_height * nKar, fig_width * nKar)
+    fig, axs = plt.subplots(nKar)
     for i, kr in enumerate(data):
-
-        axs[i].hist(data[kr].detach().numpy(), bins=bins, density=True, alpha=0.48)
+        if nKar == 1:
+            axs.hist(data[kr].detach().numpy(), bins=bins, density=True, alpha=0.48)
+            axs.title.set_text("Karyotype = " + kr)
+        else:
+            axs[i].hist(data[kr].detach().numpy(), bins=bins, density=True, alpha=0.48)
+            axs[i].title.set_text("Karyotype = " + kr)
         params = all_params[kr]
 
         karyos = list(data.keys())
@@ -40,15 +45,19 @@ def plot_results(data, inf_res, bins=50, output = "results.png",fig_height = 10,
             x = np.linspace(0.05, 1, 200)
 
             p = beta.pdf(x, a, b) * assignment_probs[j]
-
-
-            axs[i].plot(x, p, linewidth=3, color=cl)
+            if nKar == 1:
+                axs.plot(x, p, linewidth=3, color=cl)
+            else:
+                axs[i].plot(x, p, linewidth=3, color=cl)
 
         if tail == 1:
             alpha = params["tail_shape"]
             x = np.linspace(0.05, 1, 200)
             p = pareto.pdf(x, alpha, scale=params["tail_scale"]) * assignment_probs[0]
-            axs[i].plot(x, p, linewidth=3, color="tab:pink")
+            if nKar == 1:
+                axs.plot(x, p, linewidth=3, color="tab:pink")
+            else:
+                axs[i].plot(x, p, linewidth=3, color="tab:pink")
 
 
     pink_patch = mpatches.Patch(color='tab:pink', label='Tail')
